# Copyright (C) 2021, KylinSoft Co., Ltd.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
import pytest
import os
from BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status import get_env_lang,is_root,arg_lang,l_print,check_kysec_status
from BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status import get_env_lang as fix_get_env_lang,is_root as fix_is_root,l_print as fix_l_print,fix_firewall_log
def test_get_env_lang(monkeypatch):
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status.arg_lang", 'en')
    assert get_env_lang() == "语言环境为英文"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status.arg_lang", 'zh')
    assert get_env_lang() == "语言环境为中文"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status.arg_lang", '')
    assert get_env_lang() == "语言环境未知"
def test_is_root(monkeypatch):
    if os.geteuid() == 0:
        assert is_root() == True
    else:
        assert is_root() == False
def test_l_print(monkeypatch, capsys):
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status.arg_lang", 'zh')
    l_print("zh","en")
    captured = capsys.readouterr()
    assert captured.out == "zh\n"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status.arg_lang", 'en')
    l_print("zh","en")
    captured = capsys.readouterr()
    assert captured.out == "en\n"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.check_kysec_status.arg_lang", '')
    l_print("zh","en")
    captured = capsys.readouterr()
    assert captured.out == "en\n"
def test_check_kysec_status(capsys):
    check_kysec_status()
    captured = capsys.readouterr()
    assert "Kysec is disable\n" in captured.out
def test_fix_get_env_lang(monkeypatch):
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status.arg_lang", 'en')
    assert fix_get_env_lang() == "语言环境为英文"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status.arg_lang", 'zh')
    assert fix_get_env_lang() == "语言环境为中文"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status.arg_lang", '')
    assert fix_get_env_lang() == "语言环境未知"
def test_fix_is_root(monkeypatch):
    if os.geteuid() == 0:
        assert fix_is_root() == True
    else:
        assert fix_is_root() == False
def test_fix_l_print(monkeypatch, capsys):
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status.arg_lang", 'zh')
    fix_l_print("zh","en")
    captured = capsys.readouterr()
    assert captured.out == "zh\n"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status.arg_lang", 'en')
    fix_l_print("zh","en")
    captured = capsys.readouterr()
    assert captured.out == "en\n"
    monkeypatch.setattr("BaseLine.LocalServices.kysec.check_kysec_status.fix_kysec_status.arg_lang", '')
    fix_l_print("zh","en")
    captured = capsys.readouterr()
    assert captured.out == "en\n"
def test_fix_firewall_log(capsys):
    fix_firewall_log()
    captured = capsys.readouterr()
    assert "[OK] set kysec logger to enabled , need to reboot system\n" in captured.out